"use client";
import React, { useState, useEffect } from "react";
import Image from "next/image";
import { useRouter } from "next/navigation";
import SearchButton from "@/components/Buttons/SearchButton";
import vectorArrow from "@/assets/images/vector5.svg";

const SearchInputs = () => {
  const router = useRouter();

  const [country, setCountry] = useState("");
  const [city, setCity] = useState("");
  const [category, setCategory] = useState("");
  const [minPrice, setMinPrice] = useState("");
  const [maxPrice, setMaxPrice] = useState("");
  const [isLoading, setIsLoading] = useState(false);

  const handleCountryChange = (event) => {
    setCountry(event.target.value);
  };
  const handleCityChange = (event) => {
    setCity(event.target.value);
  };
  const handleCategoryChange = (event) => {
    setCategory(event.target.value);
  };
  const handleMinPriceChange = (event) => {
    setMinPrice(event.target.value);
  };
  const handleMaxPriceChange = (event) => {
    setMaxPrice(event.target.value);
  };

  const handleSearch = () => {
    setIsLoading(true);

    const query = new URLSearchParams({
      minPrice,
      maxPrice,
      country,
      city,
    });

    if (category === "Property") {
      query.append("assetType", `${category} For Sale`);
    }

    router.push(`/${category.toLowerCase()}?${query.toString()}`);
  };

  const countryOptions = [
    { fullName: "United States of America", shortName: "USA" },
    { fullName: "Canada", shortName: "Canada" },
    { fullName: "United Kingdom", shortName: "UK" },
    { fullName: "United Arab Emirates", shortName: "UAE" },
    { fullName: "India", shortName: "India" },
    { fullName: "Australia", shortName: "Australia" },
    { fullName: "Germany", shortName: "Germany" },
  ];

  useEffect(() => {
    if (category !== "Property" && country !== "") {
      const selectedCountry = countryOptions.find(
        (option) => option.fullName === country || option.shortName === country
      );
      if (selectedCountry && category === "Property") {
        setCountry(selectedCountry.fullName);
      } else if (selectedCountry && category !== "Property") {
        setCountry(selectedCountry.shortName);
      }
    }
  }, [category, country]);

  return (
    <div className="mt-14 flex gap-x-5 flex-row w-full h-16 text-xl text-darkslategray-200">
      {/* Dropdown for Country */}
      <div className="select-wrapper relative">
        <select
          className="select-custom"
          value={country}
          onChange={handleCountryChange}
        >
          <option value="" disabled hidden>
            Country
          </option>
          {countryOptions.map((option) => (
            <option
              key={option.fullName}
              value={
                category === "Property" ? option.fullName : option.shortName
              }
            >
              {option.fullName}
            </option>
          ))}
        </select>
        <div className="select-arrow">
          <Image src={vectorArrow} alt="Arrow" width={15} height={15} />
        </div>
      </div>

      {/* Dropdown for City */}
      <div className="select-wrapper relative">
        <select
          className="select-custom"
          value={city}
          onChange={handleCityChange}
        >
          <option value="" disabled hidden>
            City
          </option>
          <option>New York</option>
          <option>Toronto</option>
          <option>London</option>
          <option>Dubai</option>
          <option>Abu Dhabi</option>
          <option>Mumbai</option>
          <option>Sydney</option>
          <option>Berlin</option>
        </select>
        <div className="select-arrow relative">
          <Image src={vectorArrow} alt="Arrow" width={15} height={15} />
        </div>
      </div>

      {/* Dropdown for Categories */}
      <div className="select-wrapper relative">
        <select
          className="select-custom"
          value={category}
          onChange={handleCategoryChange}
        >
          <option value="" disabled hidden>
            Categories
          </option>
          <option value="Property">Properties</option>
          <option value="Jewelry">Jewellery</option>
          <option value="Car">Cars</option>
          <option value="Boat">Boats</option>
        </select>
        <div className="select-arrow">
          <Image src={vectorArrow} alt="Arrow" width={15} height={15} />
        </div>
      </div>

      {/* Dropdown for Min Price */}
      <div className="select-wrapper relative">
        <select
          className="select-custom"
          value={minPrice}
          onChange={handleMinPriceChange}
        >
          <option value="" disabled hidden>
            Min Price
          </option>
          <option value="1000">$1000</option>
          <option value="5000">$5000</option>
          <option value="100000">$100000</option>
        </select>
        <div className="select-arrow">
          <Image src={vectorArrow} alt="Arrow" width={15} height={15} />
        </div>
      </div>

      {/* Dropdown for Max Price */}
      <div className="select-wrapper relative">
        <select
          className="select-custom"
          value={maxPrice}
          onChange={handleMaxPriceChange}
        >
          <option value="" disabled hidden>
            Max Price
          </option>
          <option value="5000">$5000</option>
          <option value="20000">$20000</option>
          <option value="41100080">$41100080</option>
        </select>
        <div className="select-arrow">
          <Image src={vectorArrow} alt="Arrow" width={15} height={15} />
        </div>
      </div>

      {/* Search Button */}
      <div onClick={handleSearch}>
        <SearchButton isLoading={isLoading} />
      </div>
    </div>
  );
};

export default SearchInputs;
